#[repr(C)]pub struct Vec2 {
pub x: Float,
pub y: Float,
}Expand description
A 2D vector.
Fields
x: FloatX component.
y: FloatY component.
Implementations
Sourceimpl Vec2
impl Vec2
Sourcepub const fn splat(value: Float) -> Self
pub const fn splat(value: Float) -> Self
Creates a vector with all components set to the same value.
Sourcepub const fn from_array(arr: [Float; 2]) -> Self
pub const fn from_array(arr: [Float; 2]) -> Self
Creates a vector from an array.
Sourcepub fn length_squared(self) -> Float
pub fn length_squared(self) -> Float
Computes the squared length (magnitude squared).
Sourcepub fn normalize(self) -> Self
pub fn normalize(self) -> Self
Returns a normalized vector (unit length).
Returns zero vector if the length is near zero.
Sourcepub fn try_normalize(self) -> Option<Self>
pub fn try_normalize(self) -> Option<Self>
Returns a normalized vector, or None if length is near zero.
Sourcepub fn distance_squared(self, other: Self) -> Float
pub fn distance_squared(self, other: Self) -> Float
Computes the squared distance to another vector.
Sourcepub fn perpendicular(self) -> Self
pub fn perpendicular(self) -> Self
Returns a vector perpendicular to this one.
Sourcepub fn cross(self, other: Self) -> Float
pub fn cross(self, other: Self) -> Float
Computes the 2D cross product (the z-component of the 3D cross product).
Sourcepub fn angle_between(self, other: Self) -> Float
pub fn angle_between(self, other: Self) -> Float
Computes the angle in radians between two vectors.