#[repr(C)]pub struct Vec3 {
pub x: Float,
pub y: Float,
pub z: Float,
}Expand description
A 3D vector.
Fields
x: FloatX component.
y: FloatY component.
z: FloatZ component.
Implementations
Sourceimpl Vec3
impl Vec3
Sourcepub const fn splat(value: Float) -> Self
pub const fn splat(value: Float) -> Self
Creates a vector with all components set to the same value.
Sourcepub const fn from_array(arr: [Float; 3]) -> Self
pub const fn from_array(arr: [Float; 3]) -> Self
Creates a vector from an array.
Sourcepub const fn from_vec2(v: Vec2, z: Float) -> Self
pub const fn from_vec2(v: Vec2, z: Float) -> Self
Extends to Vec3 from Vec2 with a z component.
Sourcepub fn length_squared(self) -> Float
pub fn length_squared(self) -> Float
Computes the squared length.
Sourcepub fn try_normalize(self) -> Option<Self>
pub fn try_normalize(self) -> Option<Self>
Returns a normalized vector, or None if length is near zero.
Sourcepub fn distance_squared(self, other: Self) -> Float
pub fn distance_squared(self, other: Self) -> Float
Computes the squared distance to another vector.
Sourcepub fn angle_between(self, other: Self) -> Float
pub fn angle_between(self, other: Self) -> Float
Computes the angle in radians between two vectors.
Sourcepub fn approx_eq(self, other: Self) -> bool
pub fn approx_eq(self, other: Self) -> bool
Checks if this vector is approximately equal to another.