#[repr(C)]pub struct Vec4 {
pub x: Float,
pub y: Float,
pub z: Float,
pub w: Float,
}Expand description
A 4D vector.
Fields
x: FloatX component.
y: FloatY component.
z: FloatZ component.
w: FloatW component.
Implementations
Sourceimpl Vec4
impl Vec4
Sourcepub const fn splat(value: Float) -> Self
pub const fn splat(value: Float) -> Self
Creates a vector with all components set to the same value.
Sourcepub const fn from_array(arr: [Float; 4]) -> Self
pub const fn from_array(arr: [Float; 4]) -> Self
Creates a vector from an array.
Sourcepub const fn from_vec2(v: Vec2, z: Float, w: Float) -> Self
pub const fn from_vec2(v: Vec2, z: Float, w: Float) -> Self
Extends from Vec2 with z and w components.
Sourcepub fn length_squared(self) -> Float
pub fn length_squared(self) -> Float
Computes the squared length.
Sourcepub fn try_normalize(self) -> Option<Self>
pub fn try_normalize(self) -> Option<Self>
Returns a normalized vector, or None if length is near zero.